/* *******************
 * overlay.js
 * Implementation for mail and Firefox overlays 
 *   QuickNote   <http://quicknote.mozdev.org/>
 *
 * Author: Jed Brown (quicknote@jedbrown.net)
 * Contributor(s):
 *   Nickolay Ponomarev (asqueella@gmail.com)
 ******************** */


// Show CTRL+F7 in Tools menu
function QuickNote_updateKey(name, select)
{
  var menu = document.getElementById(name);
  if(menu) {
    if(!select)
      menu.removeAttribute('key');
    else
      menu.setAttribute('key', 'key_qnfocus');
  }
}

function QuickNote_updateKeys()
{
  var choice = nsPreferences.getIntPref("quicknote.openqn", 1);
  QuickNote_updateKey('quicknote-fopenfloat', choice == 1);
  QuickNote_updateKey('quicknote-mopenfloat', choice == 1);
  QuickNote_updateKey('quicknote-fopentab', choice == 2);
  QuickNote_updateKey('quicknote-mopentab', choice == 2);
  QuickNote_updateKey('quicknote-fopensidebar', choice == 0);
}

/**************** "Send to"  and  "Send link to" handlers ******************/


////////////////////////////////////////////////////////////////////////////////
// qnCopyLinkTo
//
// Send selected link to QuickNote
// If qnshowurl is true, it will also send the Referer URL.
// Thanks to the downloadwith extension for part of this link code.
////////////////////////////////////////////////////////////////////////////////
function QuickNote_qnCopyLinkTo() {
  var qnshowurl = nsPreferences.getBoolPref("quicknote.showUrl", false);
  var focusedWindow = document.commandDispatcher.focusedWindow;
  if (focusedWindow == window){
    focusedWindow = _content;
  }
        var docCharset = null;
        if (focusedWindow){
          docCharset = "charset=" + focusedWindow.document.characterSet;
	}
	var elem = document.popupNode;
	var copiedLinkToQN = null;

		if(elem) {
			if(elem instanceof Components.interfaces.nsIDOMHTMLAnchorElement && elem.href){
				copiedLinkToQN = elem.href;
			}else{
				copiedLinkToQN = elem.parentNode;
			}
		}
	var copiedLinkToQN2 = copiedLinkToQN + "\n --" + focusedWindow.location.href;
	if(!qnshowurl || qnshowurl == false){
		//alert("Cool Sent text");
		QuickNote_SendSelectedTextToQN(copiedLinkToQN);
	}else{
		//alert("Cool Sent text and refererer");
		QuickNote_SendSelectedTextToQN(copiedLinkToQN2);
	}
}


////////////////////////////////////////////////////////////////////////////////
// qnCopyTo
//
// Send selected text to QuickNote
// If qnshowurl is true, it will also send the Referer URL.
////////////////////////////////////////////////////////////////////////////////
function QuickNote_qnCopyTo() {
  var qnshowurl = nsPreferences.getBoolPref("quicknote.showUrl", false);
  var focusedWindow = document.commandDispatcher.focusedWindow;
  if (focusedWindow == window) {
    focusedWindow = _content;
  }
  var docCharset = null;
  if (focusedWindow){
    docCharset = "charset=" + focusedWindow.document.characterSet;
  }
  var copiedToQN = focusedWindow.__proto__.getSelection.call(focusedWindow);
  var copiedToQN2 = copiedToQN + "--" + focusedWindow.location.href;
  if(!qnshowurl || qnshowurl == false){
    //alert("Cool Sent text");
    QuickNote_SendSelectedTextToQN(copiedToQN);
  } else{
    //alert("Cool Sent text and refererer");
    QuickNote_SendSelectedTextToQN(copiedToQN2);
  }
}



////////////////////////////////////////////////////////////////////////////////
// SendSelectedTextToQN
//
// Desc: This get's the selected text from overlay.xul and firsts checks to see
// is QN's loaded in a window or not already, if not, opens it and does the
// send via catchText(), if already opens, it focuses the window and adds the text.
// Parameters: qnselectedtext  - this is the selected text
// Returns: nothing
// todo: Need to check Sidebar and tab
// Have to add here because Mozilla Suite won't inherit quicknote.js :(
////////////////////////////////////////////////////////////////////////////////
function QuickNote_SendSelectedTextToQN(qnselectedtext) {
  var tabtosendto = nsPreferences.getIntPref('quicknote.totabint',1);
  var myQuickNotewindow;

  myQuickNotewindow = QuickNote_getQNWinByType("quicknote:mainwindow");
  if(myQuickNotewindow && myQuickNotewindow.document.getElementById("save1").value != "Save")
  {
    myQuickNotewindow.focus();
    QuickNote_setupDocument(myQuickNotewindow.document);
    QuickNote_catchText(qnselectedtext);
  } else {
    //Open QuickNote!
    // the text will be caught via catchText() in onLoad()
    // bug #6119 [When using Send to QuickNote on OSX, the floating
    // quicknote window cannot be closed] possibly caused by this:
    window.openDialog("chrome://quicknote/content/quicknote.xul",
      "_blank", "chrome,all,dialog=no", qnselectedtext);
  }
}


////////////////////////////////////////////////////////////////////////////////
// openQNFloat
//
// Desc: Makes sure QN isn't already open in another (floating) window
// Returns: nothing
// todo: Need to check Sidebar and tab
////////////////////////////////////////////////////////////////////////////////
function openQNFloat() {
  var myQuickNotewindow2;

  myQuickNotewindow2 = QuickNote_getQNWinByType("quicknote:mainwindow");
  if(myQuickNotewindow2 && myQuickNotewindow2.document.getElementById("save1").value != "Save")
  {
    myQuickNotewindow2.focus();
  } else {
    //Open QuickNote!
    window.openDialog("chrome://quicknote/content/quicknote.xul",
      "_blank", "chrome,all,dialog=no");
  }
}


////////////////////////////////////////////////////////////////////////////////
// getQNWinByType
//
// Desc: Checks all open windows for the one we are looking for
// Parameters: type  - this is the name of the window we are looking for
// Returns: the type of window as an object.
// Have to add here because Mozilla Suite won't inherit quicknote.js :(
////////////////////////////////////////////////////////////////////////////////
function QuickNote_getQNWinByType(type) {
  var windowmanager;
  if(!windowmanager)
  {
    windowmanager = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService();
    windowmanager = windowmanager.QueryInterface( Components.interfaces.nsIWindowMediator);
  }
  return windowmanager.getMostRecentWindow(type);
}

